nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Ctrl1

Struct Ctrl1 

#[repr(transparent)]
pub struct Ctrl1(pub u32);
Control 1 Register

Tuple Fields

0: u32

Implementations

Source

impl Ctrl1

pub const fn propseg(&self) -> u8

This 3-bit field defines the length of the Propagation Segment in the bit time

pub const fn set_propseg(&mut self, val: u8)

This 3-bit field defines the length of the Propagation Segment in the bit time

pub const fn lom(&self) -> Lom

This bit configures FLEXCAN to operate in Listen Only Mode

pub const fn set_lom(&mut self, val: Lom)

This bit configures FLEXCAN to operate in Listen Only Mode

pub const fn lbuf(&self) -> Lbuf

This bit defines the ordering mechanism for Message Buffer transmission

pub const fn set_lbuf(&mut self, val: Lbuf)

This bit defines the ordering mechanism for Message Buffer transmission

pub const fn tsyn(&self) -> Tsyn

This bit enables a mechanism that resets the free-running timer each time a message is received in Message Buffer 0

pub const fn set_tsyn(&mut self, val: Tsyn)

This bit enables a mechanism that resets the free-running timer each time a message is received in Message Buffer 0

pub const fn boffrec(&self) -> Boffrec

This bit defines how FLEXCAN recovers from Bus Off state

pub const fn set_boffrec(&mut self, val: Boffrec)

This bit defines how FLEXCAN recovers from Bus Off state

pub const fn smp(&self) -> Smp

This bit defines the sampling mode of CAN bits at the FLEXCAN_RX

pub const fn set_smp(&mut self, val: Smp)

This bit defines the sampling mode of CAN bits at the FLEXCAN_RX

pub const fn rwrnmsk(&self) -> Rwrnmsk

This bit provides a mask for the Rx Warning Interrupt associated with the RWRN_INT flag in the Error and Status Register

pub const fn set_rwrnmsk(&mut self, val: Rwrnmsk)

This bit provides a mask for the Rx Warning Interrupt associated with the RWRN_INT flag in the Error and Status Register

pub const fn twrnmsk(&self) -> Twrnmsk

This bit provides a mask for the Tx Warning Interrupt associated with the TWRN_INT flag in the Error and Status Register

pub const fn set_twrnmsk(&mut self, val: Twrnmsk)

This bit provides a mask for the Tx Warning Interrupt associated with the TWRN_INT flag in the Error and Status Register

pub const fn lpb(&self) -> Lpb

This bit configures FlexCAN to operate in Loop-Back Mode

pub const fn set_lpb(&mut self, val: Lpb)

This bit configures FlexCAN to operate in Loop-Back Mode

pub const fn errmsk(&self) -> Errmsk

This bit provides a mask for the Error Interrupt.

pub const fn set_errmsk(&mut self, val: Errmsk)

This bit provides a mask for the Error Interrupt.

pub const fn boffmsk(&self) -> Boffmsk

This bit provides a mask for the Bus Off Interrupt.

pub const fn set_boffmsk(&mut self, val: Boffmsk)

This bit provides a mask for the Bus Off Interrupt.

pub const fn pseg2(&self) -> u8

This 3-bit field defines the length of Phase Buffer Segment 2 in the bit time

pub const fn set_pseg2(&mut self, val: u8)

This 3-bit field defines the length of Phase Buffer Segment 2 in the bit time

pub const fn pseg1(&self) -> u8

This 3-bit field defines the length of Phase Buffer Segment 1 in the bit time

pub const fn set_pseg1(&mut self, val: u8)

This 3-bit field defines the length of Phase Buffer Segment 1 in the bit time

pub const fn rjw(&self) -> u8

This 2-bit field defines the maximum number of time quanta One time quantum is equal to the Sclock period

pub const fn set_rjw(&mut self, val: u8)

This 2-bit field defines the maximum number of time quanta One time quantum is equal to the Sclock period

pub const fn presdiv(&self) -> u8

This 8-bit field defines the ratio between the PE clock frequency and the Serial Clock (Sclock) frequency

pub const fn set_presdiv(&mut self, val: u8)

This 8-bit field defines the ratio between the PE clock frequency and the Serial Clock (Sclock) frequency