nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Ctrl2

Struct Ctrl2 

#[repr(transparent)]
pub struct Ctrl2(pub u32);
Control 2 Register

Tuple Fields

0: u32

Implementations

Source

impl Ctrl2

pub const fn eacen(&self) -> Eacen

This bit controls the comparison of IDE and RTR bits within Rx Mailboxes filters with their corresponding bits in the incoming frame by the matching process

pub const fn set_eacen(&mut self, val: Eacen)

This bit controls the comparison of IDE and RTR bits within Rx Mailboxes filters with their corresponding bits in the incoming frame by the matching process

pub const fn rrs(&self) -> Rrs

If this bit is asserted Remote Request Frame is submitted to a matching process and stored in the corresponding Message Buffer in the same fashion of a Data Frame

pub const fn set_rrs(&mut self, val: Rrs)

If this bit is asserted Remote Request Frame is submitted to a matching process and stored in the corresponding Message Buffer in the same fashion of a Data Frame

pub const fn mrp(&self) -> Mrp

If this bit is set the matching process starts from the Mailboxes and if no match occurs the matching continues on the Rx FIFO

pub const fn set_mrp(&mut self, val: Mrp)

If this bit is set the matching process starts from the Mailboxes and if no match occurs the matching continues on the Rx FIFO

pub const fn tasd(&self) -> u8

This 5-bit field indicates how many CAN bits the Tx arbitration process start point can be delayed from the first bit of CRC field on CAN bus

pub const fn set_tasd(&mut self, val: u8)

This 5-bit field indicates how many CAN bits the Tx arbitration process start point can be delayed from the first bit of CRC field on CAN bus

pub const fn rffn(&self) -> u8

This 4-bit field defines the number of Rx FIFO filters according to

pub const fn set_rffn(&mut self, val: u8)

This 4-bit field defines the number of Rx FIFO filters according to

pub const fn wrmfrz(&self) -> Wrmfrz

Enable unrestricted write access to FlexCAN memory in Freeze mode

pub const fn set_wrmfrz(&mut self, val: Wrmfrz)

Enable unrestricted write access to FlexCAN memory in Freeze mode