#[repr(transparent)]pub struct Esr2(pub u32);Expand description
Error and Status 2 Register
Tuple Fields
0: u32Implementations
Sourceimpl Esr2
impl Esr2
Sourcepub const fn imb(&self) -> Imb
pub const fn imb(&self) -> Imb
If ESR2[VPS] is asserted, this bit indicates whether there is any inactive Mailbox (CODE field is either 0b1000 or 0b0000)
Sourcepub const fn set_imb(&mut self, val: Imb)
pub const fn set_imb(&mut self, val: Imb)
If ESR2[VPS] is asserted, this bit indicates whether there is any inactive Mailbox (CODE field is either 0b1000 or 0b0000)
Sourcepub const fn vps(&self) -> Vps
pub const fn vps(&self) -> Vps
This bit indicates whether IMB and LPTM contents are currently valid or not
Sourcepub const fn set_vps(&mut self, val: Vps)
pub const fn set_vps(&mut self, val: Vps)
This bit indicates whether IMB and LPTM contents are currently valid or not