nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Rxmgmask

Struct Rxmgmask 

#[repr(transparent)]
pub struct Rxmgmask(pub u32);
Rx Mailboxes Global Mask Register

Tuple Fields

0: u32

Implementations

Source

impl Rxmgmask

pub const fn mg(&self) -> Mg

These bits mask the Mailbox filter bits as shown in the figure above

pub const fn set_mg(&mut self, val: Mg)

These bits mask the Mailbox filter bits as shown in the figure above