#[repr(transparent)]pub struct Ctrl1(pub u32);Expand description
Control 1 Register
Tuple Fields
0: u32Implementations
Sourceimpl Ctrl1
impl Ctrl1
Sourcepub const fn propseg(&self) -> u8
pub const fn propseg(&self) -> u8
This 3-bit field defines the length of the Propagation Segment in the bit time
Sourcepub const fn set_propseg(&mut self, val: u8)
pub const fn set_propseg(&mut self, val: u8)
This 3-bit field defines the length of the Propagation Segment in the bit time
Sourcepub const fn set_lom(&mut self, val: Lom)
pub const fn set_lom(&mut self, val: Lom)
This bit configures FLEXCAN to operate in Listen Only Mode
Sourcepub const fn lbuf(&self) -> Lbuf
pub const fn lbuf(&self) -> Lbuf
This bit defines the ordering mechanism for Message Buffer transmission
Sourcepub const fn set_lbuf(&mut self, val: Lbuf)
pub const fn set_lbuf(&mut self, val: Lbuf)
This bit defines the ordering mechanism for Message Buffer transmission
Sourcepub const fn tsyn(&self) -> Tsyn
pub const fn tsyn(&self) -> Tsyn
This bit enables a mechanism that resets the free-running timer each time a message is received in Message Buffer 0
Sourcepub const fn set_tsyn(&mut self, val: Tsyn)
pub const fn set_tsyn(&mut self, val: Tsyn)
This bit enables a mechanism that resets the free-running timer each time a message is received in Message Buffer 0
Sourcepub const fn boffrec(&self) -> Boffrec
pub const fn boffrec(&self) -> Boffrec
This bit defines how FLEXCAN recovers from Bus Off state
Sourcepub const fn set_boffrec(&mut self, val: Boffrec)
pub const fn set_boffrec(&mut self, val: Boffrec)
This bit defines how FLEXCAN recovers from Bus Off state
Sourcepub const fn smp(&self) -> Smp
pub const fn smp(&self) -> Smp
This bit defines the sampling mode of CAN bits at the FLEXCAN_RX
Sourcepub const fn set_smp(&mut self, val: Smp)
pub const fn set_smp(&mut self, val: Smp)
This bit defines the sampling mode of CAN bits at the FLEXCAN_RX
Sourcepub const fn rwrnmsk(&self) -> Rwrnmsk
pub const fn rwrnmsk(&self) -> Rwrnmsk
This bit provides a mask for the Rx Warning Interrupt associated with the RWRN_INT flag in the Error and Status Register
Sourcepub const fn set_rwrnmsk(&mut self, val: Rwrnmsk)
pub const fn set_rwrnmsk(&mut self, val: Rwrnmsk)
This bit provides a mask for the Rx Warning Interrupt associated with the RWRN_INT flag in the Error and Status Register
Sourcepub const fn twrnmsk(&self) -> Twrnmsk
pub const fn twrnmsk(&self) -> Twrnmsk
This bit provides a mask for the Tx Warning Interrupt associated with the TWRN_INT flag in the Error and Status Register
Sourcepub const fn set_twrnmsk(&mut self, val: Twrnmsk)
pub const fn set_twrnmsk(&mut self, val: Twrnmsk)
This bit provides a mask for the Tx Warning Interrupt associated with the TWRN_INT flag in the Error and Status Register
Sourcepub const fn set_lpb(&mut self, val: Lpb)
pub const fn set_lpb(&mut self, val: Lpb)
This bit configures FlexCAN to operate in Loop-Back Mode
Sourcepub const fn set_errmsk(&mut self, val: Errmsk)
pub const fn set_errmsk(&mut self, val: Errmsk)
This bit provides a mask for the Error Interrupt.
Sourcepub const fn set_boffmsk(&mut self, val: Boffmsk)
pub const fn set_boffmsk(&mut self, val: Boffmsk)
This bit provides a mask for the Bus Off Interrupt.
Sourcepub const fn pseg2(&self) -> u8
pub const fn pseg2(&self) -> u8
This 3-bit field defines the length of Phase Buffer Segment 2 in the bit time
Sourcepub const fn set_pseg2(&mut self, val: u8)
pub const fn set_pseg2(&mut self, val: u8)
This 3-bit field defines the length of Phase Buffer Segment 2 in the bit time
Sourcepub const fn pseg1(&self) -> u8
pub const fn pseg1(&self) -> u8
This 3-bit field defines the length of Phase Buffer Segment 1 in the bit time
Sourcepub const fn set_pseg1(&mut self, val: u8)
pub const fn set_pseg1(&mut self, val: u8)
This 3-bit field defines the length of Phase Buffer Segment 1 in the bit time
Sourcepub const fn rjw(&self) -> u8
pub const fn rjw(&self) -> u8
This 2-bit field defines the maximum number of time quanta One time quantum is equal to the Sclock period
Sourcepub const fn set_rjw(&mut self, val: u8)
pub const fn set_rjw(&mut self, val: u8)
This 2-bit field defines the maximum number of time quanta One time quantum is equal to the Sclock period
Sourcepub const fn presdiv(&self) -> u8
pub const fn presdiv(&self) -> u8
This 8-bit field defines the ratio between the PE clock frequency and the Serial Clock (Sclock) frequency
Sourcepub const fn set_presdiv(&mut self, val: u8)
pub const fn set_presdiv(&mut self, val: u8)
This 8-bit field defines the ratio between the PE clock frequency and the Serial Clock (Sclock) frequency