#[repr(transparent)]pub struct Esr1(pub u32);Expand description
Error and Status 1 Register
Tuple Fields
0: u32Implementations
Sourceimpl Esr1
impl Esr1
Sourcepub const fn wakint(&self) -> Wakint
pub const fn wakint(&self) -> Wakint
When FLEXCAN is Stop Mode and a recessive to dominant transition is detected on the CAN bus and if the WAK_MSK bit in the MCR Register is set, an interrupt is generated to the Arm
Sourcepub const fn set_wakint(&mut self, val: Wakint)
pub const fn set_wakint(&mut self, val: Wakint)
When FLEXCAN is Stop Mode and a recessive to dominant transition is detected on the CAN bus and if the WAK_MSK bit in the MCR Register is set, an interrupt is generated to the Arm
Sourcepub const fn errint(&self) -> Errint
pub const fn errint(&self) -> Errint
This bit indicates that at least one of the Error Bits (bits 15-10) is set
Sourcepub const fn set_errint(&mut self, val: Errint)
pub const fn set_errint(&mut self, val: Errint)
This bit indicates that at least one of the Error Bits (bits 15-10) is set
Sourcepub const fn set_boffint(&mut self, val: Boffint)
pub const fn set_boffint(&mut self, val: Boffint)
This bit is set when FLEXCAN enters ‘Bus Off’ state
Sourcepub const fn set_rx(&mut self, val: Rx)
pub const fn set_rx(&mut self, val: Rx)
This bit indicates if FlexCAN is receiving a message. Refer to .
Sourcepub const fn fltconf(&self) -> Fltconf
pub const fn fltconf(&self) -> Fltconf
If the LOM bit in the Control Register is asserted, after some delay that depends on the CAN bit timing the FLT_CONF field will indicate “Error Passive”
Sourcepub const fn set_fltconf(&mut self, val: Fltconf)
pub const fn set_fltconf(&mut self, val: Fltconf)
If the LOM bit in the Control Register is asserted, after some delay that depends on the CAN bit timing the FLT_CONF field will indicate “Error Passive”
Sourcepub const fn tx(&self) -> Tx
pub const fn tx(&self) -> Tx
This bit indicates if FLEXCAN is transmitting a message.Refer to .
Sourcepub const fn set_tx(&mut self, val: Tx)
pub const fn set_tx(&mut self, val: Tx)
This bit indicates if FLEXCAN is transmitting a message.Refer to .
Sourcepub const fn set_idle(&mut self, val: Idle)
pub const fn set_idle(&mut self, val: Idle)
This bit indicates when CAN bus is in IDLE state.Refer to .
Sourcepub const fn rxwrn(&self) -> Rxwrn
pub const fn rxwrn(&self) -> Rxwrn
This bit indicates when repetitive errors are occurring during message reception.
Sourcepub const fn set_rxwrn(&mut self, val: Rxwrn)
pub const fn set_rxwrn(&mut self, val: Rxwrn)
This bit indicates when repetitive errors are occurring during message reception.
Sourcepub const fn txwrn(&self) -> Txwrn
pub const fn txwrn(&self) -> Txwrn
This bit indicates when repetitive errors are occurring during message transmission.
Sourcepub const fn set_txwrn(&mut self, val: Txwrn)
pub const fn set_txwrn(&mut self, val: Txwrn)
This bit indicates when repetitive errors are occurring during message transmission.
Sourcepub const fn stferr(&self) -> Stferr
pub const fn stferr(&self) -> Stferr
This bit indicates that a Stuffing Error has been detected.
Sourcepub const fn set_stferr(&mut self, val: Stferr)
pub const fn set_stferr(&mut self, val: Stferr)
This bit indicates that a Stuffing Error has been detected.
Sourcepub const fn frmerr(&self) -> Frmerr
pub const fn frmerr(&self) -> Frmerr
This bit indicates that a Form Error has been detected by the receiver node, i
Sourcepub const fn set_frmerr(&mut self, val: Frmerr)
pub const fn set_frmerr(&mut self, val: Frmerr)
This bit indicates that a Form Error has been detected by the receiver node, i
Sourcepub const fn crcerr(&self) -> Crcerr
pub const fn crcerr(&self) -> Crcerr
This bit indicates that a CRC Error has been detected by the receiver node, i
Sourcepub const fn set_crcerr(&mut self, val: Crcerr)
pub const fn set_crcerr(&mut self, val: Crcerr)
This bit indicates that a CRC Error has been detected by the receiver node, i
Sourcepub const fn ackerr(&self) -> Ackerr
pub const fn ackerr(&self) -> Ackerr
This bit indicates that an Acknowledge Error has been detected by the transmitter node, i
Sourcepub const fn set_ackerr(&mut self, val: Ackerr)
pub const fn set_ackerr(&mut self, val: Ackerr)
This bit indicates that an Acknowledge Error has been detected by the transmitter node, i
Sourcepub const fn bit0err(&self) -> Bit0err
pub const fn bit0err(&self) -> Bit0err
This bit indicates when an inconsistency occurs between the transmitted and the received bit in a message
Sourcepub const fn set_bit0err(&mut self, val: Bit0err)
pub const fn set_bit0err(&mut self, val: Bit0err)
This bit indicates when an inconsistency occurs between the transmitted and the received bit in a message
Sourcepub const fn bit1err(&self) -> Bit1err
pub const fn bit1err(&self) -> Bit1err
This bit indicates when an inconsistency occurs between the transmitted and the received bit in a message
Sourcepub const fn set_bit1err(&mut self, val: Bit1err)
pub const fn set_bit1err(&mut self, val: Bit1err)
This bit indicates when an inconsistency occurs between the transmitted and the received bit in a message
Sourcepub const fn rwrnint(&self) -> Rwrnint
pub const fn rwrnint(&self) -> Rwrnint
If the WRN_EN bit in MCR is asserted, the RWRN_INT bit is set when the RX_WRN flag transition from ‘0’ to ‘1’, meaning that the Rx error counters reached 96
Sourcepub const fn set_rwrnint(&mut self, val: Rwrnint)
pub const fn set_rwrnint(&mut self, val: Rwrnint)
If the WRN_EN bit in MCR is asserted, the RWRN_INT bit is set when the RX_WRN flag transition from ‘0’ to ‘1’, meaning that the Rx error counters reached 96
Sourcepub const fn twrnint(&self) -> Twrnint
pub const fn twrnint(&self) -> Twrnint
If the WRN_EN bit in MCR is asserted, the TWRN_INT bit is set when the TX_WRN flag transition from ‘0’ to ‘1’, meaning that the Tx error counter reached 96
Sourcepub const fn set_twrnint(&mut self, val: Twrnint)
pub const fn set_twrnint(&mut self, val: Twrnint)
If the WRN_EN bit in MCR is asserted, the TWRN_INT bit is set when the TX_WRN flag transition from ‘0’ to ‘1’, meaning that the Tx error counter reached 96