#[repr(transparent)]pub struct Iflag1(pub u32);Expand description
Interrupt Flags 1 Register
Tuple Fields
0: u32Implementations
Sourceimpl Iflag1
impl Iflag1
Sourcepub const fn buf4to0i(&self) -> Buf4to0i
pub const fn buf4to0i(&self) -> Buf4to0i
If the Rx FIFO is not enabled, these bits flag the interrupts for MB0 to MB4
Sourcepub const fn set_buf4to0i(&mut self, val: Buf4to0i)
pub const fn set_buf4to0i(&mut self, val: Buf4to0i)
If the Rx FIFO is not enabled, these bits flag the interrupts for MB0 to MB4
Sourcepub const fn buf5i(&self) -> Buf5i
pub const fn buf5i(&self) -> Buf5i
If the Rx FIFO is not enabled, this bit flags the interrupt for MB5
Sourcepub const fn set_buf5i(&mut self, val: Buf5i)
pub const fn set_buf5i(&mut self, val: Buf5i)
If the Rx FIFO is not enabled, this bit flags the interrupt for MB5
Sourcepub const fn buf6i(&self) -> Buf6i
pub const fn buf6i(&self) -> Buf6i
If the Rx FIFO is not enabled, this bit flags the interrupt for MB6
Sourcepub const fn set_buf6i(&mut self, val: Buf6i)
pub const fn set_buf6i(&mut self, val: Buf6i)
If the Rx FIFO is not enabled, this bit flags the interrupt for MB6
Sourcepub const fn buf7i(&self) -> Buf7i
pub const fn buf7i(&self) -> Buf7i
If the Rx FIFO is not enabled, this bit flags the interrupt for MB7
Sourcepub const fn set_buf7i(&mut self, val: Buf7i)
pub const fn set_buf7i(&mut self, val: Buf7i)
If the Rx FIFO is not enabled, this bit flags the interrupt for MB7
Sourcepub const fn buf31to8i(&self) -> Buf31to8i
pub const fn buf31to8i(&self) -> Buf31to8i
Each bit flags the respective FLEXCAN Message Buffer (MB8 to MB31) interrupt.
Sourcepub const fn set_buf31to8i(&mut self, val: Buf31to8i)
pub const fn set_buf31to8i(&mut self, val: Buf31to8i)
Each bit flags the respective FLEXCAN Message Buffer (MB8 to MB31) interrupt.