#[repr(transparent)]pub struct Mcr(pub u32);Expand description
Module Configuration Register
Tuple Fields
0: u32Implementations
Sourceimpl Mcr
impl Mcr
Sourcepub const fn maxmb(&self) -> u8
pub const fn maxmb(&self) -> u8
This 7-bit field defines the number of the last Message Buffers that will take part in the matching and arbitration processes
Sourcepub const fn set_maxmb(&mut self, val: u8)
pub const fn set_maxmb(&mut self, val: u8)
This 7-bit field defines the number of the last Message Buffers that will take part in the matching and arbitration processes
Sourcepub const fn idam(&self) -> Idam
pub const fn idam(&self) -> Idam
This 2-bit field identifies the format of the elements of the Rx FIFO filter table, as shown below
Sourcepub const fn set_idam(&mut self, val: Idam)
pub const fn set_idam(&mut self, val: Idam)
This 2-bit field identifies the format of the elements of the Rx FIFO filter table, as shown below
Sourcepub const fn set_aen(&mut self, val: Aen)
pub const fn set_aen(&mut self, val: Aen)
This bit is supplied for backwards compatibility reasons
Sourcepub const fn lprioen(&self) -> Lprioen
pub const fn lprioen(&self) -> Lprioen
This bit is provided for backwards compatibility reasons
Sourcepub const fn set_lprioen(&mut self, val: Lprioen)
pub const fn set_lprioen(&mut self, val: Lprioen)
This bit is provided for backwards compatibility reasons
Sourcepub const fn irmq(&self) -> Irmq
pub const fn irmq(&self) -> Irmq
This bit indicates whether Rx matching process will be based either on individual masking and queue or on masking scheme with RXMGMASK, RX14MASK and RX15MASK, RXFGMASK
Sourcepub const fn set_irmq(&mut self, val: Irmq)
pub const fn set_irmq(&mut self, val: Irmq)
This bit indicates whether Rx matching process will be based either on individual masking and queue or on masking scheme with RXMGMASK, RX14MASK and RX15MASK, RXFGMASK
Sourcepub const fn srxdis(&self) -> Srxdis
pub const fn srxdis(&self) -> Srxdis
This bit defines whether FlexCAN is allowed to receive frames transmitted by itself
Sourcepub const fn set_srxdis(&mut self, val: Srxdis)
pub const fn set_srxdis(&mut self, val: Srxdis)
This bit defines whether FlexCAN is allowed to receive frames transmitted by itself
Sourcepub const fn waksrc(&self) -> Waksrc
pub const fn waksrc(&self) -> Waksrc
This bit defines whether the integrated low-pass filter is applied to protect the FLEXCAN_RX input from spurious wake up
Sourcepub const fn set_waksrc(&mut self, val: Waksrc)
pub const fn set_waksrc(&mut self, val: Waksrc)
This bit defines whether the integrated low-pass filter is applied to protect the FLEXCAN_RX input from spurious wake up
Sourcepub const fn lpmack(&self) -> Lpmack
pub const fn lpmack(&self) -> Lpmack
This read-only bit indicates that FLEXCAN is either in Disable Mode or Stop Mode
Sourcepub const fn set_lpmack(&mut self, val: Lpmack)
pub const fn set_lpmack(&mut self, val: Lpmack)
This read-only bit indicates that FLEXCAN is either in Disable Mode or Stop Mode
Sourcepub const fn wrnen(&self) -> Wrnen
pub const fn wrnen(&self) -> Wrnen
When asserted, this bit enables the generation of the TWRN_INT and RWRN_INT flags in the Error and Status Register
Sourcepub const fn set_wrnen(&mut self, val: Wrnen)
pub const fn set_wrnen(&mut self, val: Wrnen)
When asserted, this bit enables the generation of the TWRN_INT and RWRN_INT flags in the Error and Status Register
Sourcepub const fn slfwak(&self) -> Slfwak
pub const fn slfwak(&self) -> Slfwak
This bit enables the Self Wake Up feature when FLEXCAN is in Stop Mode
Sourcepub const fn set_slfwak(&mut self, val: Slfwak)
pub const fn set_slfwak(&mut self, val: Slfwak)
This bit enables the Self Wake Up feature when FLEXCAN is in Stop Mode
Sourcepub const fn supv(&self) -> Supv
pub const fn supv(&self) -> Supv
This bit configures some of the FLEXCAN registers to be either in Supervisor or User Mode
Sourcepub const fn set_supv(&mut self, val: Supv)
pub const fn set_supv(&mut self, val: Supv)
This bit configures some of the FLEXCAN registers to be either in Supervisor or User Mode
Sourcepub const fn frzack(&self) -> Frzack
pub const fn frzack(&self) -> Frzack
This read-only bit indicates that FLEXCAN is in Freeze Mode and its prescaler is stopped
Sourcepub const fn set_frzack(&mut self, val: Frzack)
pub const fn set_frzack(&mut self, val: Frzack)
This read-only bit indicates that FLEXCAN is in Freeze Mode and its prescaler is stopped
Sourcepub const fn softrst(&self) -> Softrst
pub const fn softrst(&self) -> Softrst
When this bit is asserted, FlexCAN resets its internal state machines and some of the memory mapped registers
Sourcepub const fn set_softrst(&mut self, val: Softrst)
pub const fn set_softrst(&mut self, val: Softrst)
When this bit is asserted, FlexCAN resets its internal state machines and some of the memory mapped registers
Sourcepub const fn set_wakmsk(&mut self, val: Wakmsk)
pub const fn set_wakmsk(&mut self, val: Wakmsk)
This bit enables the Wake Up Interrupt generation.
Sourcepub const fn notrdy(&self) -> Notrdy
pub const fn notrdy(&self) -> Notrdy
This read-only bit indicates that FLEXCAN is either in Disable Mode, Stop Mode or Freeze Mode
Sourcepub const fn set_notrdy(&mut self, val: Notrdy)
pub const fn set_notrdy(&mut self, val: Notrdy)
This read-only bit indicates that FLEXCAN is either in Disable Mode, Stop Mode or Freeze Mode
Sourcepub const fn halt(&self) -> Halt
pub const fn halt(&self) -> Halt
Assertion of this bit puts the FLEXCAN module into Freeze Mode
Sourcepub const fn set_halt(&mut self, val: Halt)
pub const fn set_halt(&mut self, val: Halt)
Assertion of this bit puts the FLEXCAN module into Freeze Mode
Sourcepub const fn rfen(&self) -> Rfen
pub const fn rfen(&self) -> Rfen
This bit controls whether the Rx FIFO feature is enabled or not
Sourcepub const fn set_rfen(&mut self, val: Rfen)
pub const fn set_rfen(&mut self, val: Rfen)
This bit controls whether the Rx FIFO feature is enabled or not
Sourcepub const fn frz(&self) -> Frz
pub const fn frz(&self) -> Frz
The FRZ bit specifies the FLEXCAN behavior when the HALT bit in the MCR Register is set or when Debug Mode is requested at Arm level